Citation
==========

|doibadages|

.. note:: :mod:`pyrolite` began as a personal project, but as the project develops
          there are likely to be other contributors. Check the
          `Contributors list <./contributors.html>`__ and add major contributors as
          authors.

If you use :mod:`pyrolite` extensively for your research, citation of the software
would be particularly appreciated. It helps quantify the impact of the project
(assisting those contributing through paid and volunteer work), and is one way to get
the message out and help build the pyrolite community.

:mod:`pyrolite` has been published in the Journal of Open Source Software (JOSS),
and generally this paper is what you should cite. This paper was published in reference
to :mod:`pyrolite` v0.2.7; if you're using a different version please note that in the
citation.

While the exact format of your citation will vary
with wherever you're publishing, it should take the general form:

  Williams et al., (2020). pyrolite: Python for geochemistry.
  Journal of Open Source Software, 5(50), 2314,
  doi: `10.21105/joss.02314 <https://doi.org/10.21105/joss.02314>`__

Or, if you wish to cite a specific version of the archive:

  Williams et al. (|year|). pyrolite v |version|, Zenodo,
  `doi:10.5281/zenodo.2545106 <https://dx.doi.org/doi:10.5281/zenodo.2545106>`__

If you're after a BibTeX citation for :mod:`pyrolite`, I've added one below.

.. code-block:: latex

  @article{Williams2020,
    title = {pyrolite: Python for geochemistry},
    author = {Morgan J. Williams and
              Louise Schoneveld and
              Yajing Mao and
              Jens Klump and
              Justin Gosses and
              Hayden Dalton and
              Adam Bath and
              Steve Barnes},
    year = {2020},
    journal = {Journal of Open Source Software}
    doi = {10.21105/joss.02314},
    url = {https://doi.org/10.21105/joss.02314},
    publisher = {The Open Journal},
    volume = {5},
    number = {50},
    pages = {2314},
  }

If you're using :mod:`pyrolite`'s implementation of `lambdas`, please consider
citing a more recent publication directly related to this:

  Anenburg, M., & Williams, M. J. (2021). Quantifying the Tetrad Effect,
  Shape Components, and Ce–Eu–Gd Anomalies in Rare Earth Element Patterns.
  Mathematical Geosciences.
  doi: `10.1007/s11004-021-09959-5 <https://doi.org/10.1007/s11004-021-09959-5>`__


Or, if you're using BibTeX:

.. code-block:: latex

  @article{Anenburg_Williams_2021,
    title={Quantifying the Tetrad Effect, Shape Components,
          and Ce–Eu–Gd Anomalies in Rare Earth Element Patterns},
    author={Anenburg, Michael and Williams, Morgan J.},
    year={2021},
    journal={Mathematical Geosciences},
    doi={10.1007/s11004-021-09959-5},
    url={https://doi.org/10.1007/s11004-021-09959-5},
    ISSN={1874-8953},
    month={Jul}
  }
